@@ -1,7 +1,9 @@
 """Defines constants and utility used throughout the project"""
 import json
+import logging
 import os
 import platform
+import re
 
 from appdirs import user_config_dir
 
@@ -15,6 +17,9 @@ OSX = platform.system().startswith("Darwin")
 LINUX = not WINDOWS and not OSX
 
 
+logger = logging.getLogger()
+
+
 def get_build_modes():
     """Returns the build modes supported by UBT"""
     return ["Tests", "Debug", "Development", "Shipping"]
@@ -62,7 +67,7 @@ def load_conf():
     if not os.path.exists(config):
         return {}
 
-    with open(config, "r", encoding="utf-8") as conffile:
+    with open(config, encoding="utf-8") as conffile:
         conf = json.load(conffile)
 
     LATEST_CONF = conf
@@ -126,6 +131,27 @@ def uat():
     return os.path.join(engine, "Build", "BatchFiles", bash("RunUAT"))
 
 
+def uat_exec():
+    """Returns the compiled automation tool"""
+    engine = engine_folder()
+
+    uat_directory = os.path.join(engine, "Binaries", "DotNet", "AutomationTool")
+    uat_exec = "AutomationTool.dll"
+
+    if WINDOWS:
+        return os.path.join(uat_directory, uat_exec)
+
+    raise NotImplementedError()
+
+
+def dotnet():
+    """Return the dotnet executable to run c# programs"""
+    if WINDOWS:
+        return "dotnet"
+
+    raise NotImplementedError()
+
+
 def editor():
     """Returns the path to the editor executable"""
     engine = engine_folder()
@@ -274,14 +300,71 @@ def find_project(name):
     raise RuntimeError(f"None of {uproject_project}, {uproject_engine} exist")
 
 
+class ConfigurationError(Exception):
+    """Raised when uetools has not been configured yet"""
+
+
 def project_folder():
     """Returns the folder user to store projects"""
-    return load_conf().get("project_path")
+    p = load_conf().get("project_path")
+
+    if p is None:
+        logger.warning(
+            "Project folder is not defined, using UnrealEngine root as default"
+        )
+        return engine_root()
+
+    return p
+
+
+PRECOMPILED_UE_VERSION = re.compile(r"UE_(?P<Major>[0-9]*)\.(?P<Minor>\d{1,})")
+
+
+def find_engine(installfolder):
+    """Look for the precompiled UE version people install from the Launcher"""
+    if not os.path.exists(installfolder):
+        print("Could not find UnrealEngine installation path")
+        return None
+
+    folders = os.listdir(installfolder)
+    found = []
+    for folder in folders:
+        if PRECOMPILED_UE_VERSION.match(folder):
+            found.append(folder)
+
+    if found:
+        print("Found UnrealEngine installation...")
+
+        for folder in found:
+            print(" - ", installfolder + folder)
+
+        return [os.path.join(installfolder, folder) for folder in found]
+
+    print("Found installation path {installfolder} but no Engine was found")
+    return []
+
+
+def guess_engine_folder():
+    """Try to guess the engine location by looking at standard locations"""
+    default_paths = ["C:/Program Files/Epic Games/"]
+
+    engines = []
+    for path in default_paths:
+        engines.extend(find_engine(path))
+
+    raise RuntimeError("Not implemented")
 
 
 def engine_folder():
     """returns the engine folder ``UnrealEngine/Engine``"""
-    return load_conf().get("engine_path")
+    p = load_conf().get("engine_path")
+
+    if p is None:
+        raise ConfigurationError(
+            "Engine path is missing; call `uecli init --engine <...> --projects <...>` first"
+        )
+
+    return p
 
 
 def engine_root():
@@ -291,4 +374,4 @@ def engine_root():
 
 def ready():
     """Returns true if uetools was initialized"""
-    return load_conf().get("project_path") is not None
+    return load_conf().get("engine_path") is not None
